@@ -521,8 +521,8 @@ for(;;)
 					{
 					/* if((*pnt == '[')||(isspace(*pnt))) break; */
 
-					if(isspace(*pnt)) break;
-					if((*pnt == '[') && (pnt == strrchr(pnt, '['))) /* fix for arrays */
+ 					if(isspace(*pnt)) break;
+					if((*pnt == '[') && (pnt == strrchr(pnt, '[')) && (GLOBALS->mvlfacs_vzt_c_3[i].flags != VZT_RD_SYM_F_DOUBLE)) /* fix for arrays */
 						{
 						/* now to fix possible generate... */
 						char *pnt2 = pnt;
@@ -1145,10 +1145,19 @@ static char zbuf[65537]; /* OK as this does not need to be re-entrant */
 				{
 				while(*pnt)
 					{
-					/* if((*pnt == '[')||(isspace(*pnt))) break; */
-
-					if(isspace(*pnt)) break;
-					if((*pnt == '[') && (pnt == strrchr(pnt, '['))) /* fix for arrays */
+					if(isspace(*pnt))
+						{
+						if(fh->u.var.typ == FST_VT_VCD_REAL)
+							{
+							pnt++;
+							continue;
+							}
+							else
+							{
+							break;
+							}
+						}
+					if((*pnt == '[') && (pnt == strrchr(pnt, '[')) && (fh->u.var.typ != FST_VT_VCD_REAL)) /* fix for arrays */
 						{
 						/* now to fix possible generate... */
 						const char *pnt2 = pnt;
